@@ -4,7 +4,7 @@
 # the git version and the date of the last commit.
 # Needs git, tar and python3-dev (to run the waf)
 
-UPSTREAM_GIT_URL=https://github.com/tomszilagyi/zutty.git
+UPSTREAM_GIT_URL=https://git.hq.sig7.se/zutty.git
 TARGET=zutty
 DFSG=1
 
